@@ -1,13 +1,17 @@
 package Pithub::Repos;
 our $AUTHORITY = 'cpan:PLU';
-our $VERSION = '0.01039';
+
 # ABSTRACT: Github v3 Repos API
 
 use Moo;
+
+our $VERSION = '0.01040';
+
 use Carp qw( croak );
 use Pithub::Issues;
 use Pithub::Markdown;
 use Pithub::PullRequests;
+use Pithub::Repos::Actions ();
 use Pithub::Repos::Collaborators;
 use Pithub::Repos::Commits;
 use Pithub::Repos::Contents;
@@ -20,9 +24,15 @@ use Pithub::Repos::Starring;
 use Pithub::Repos::Stats;
 use Pithub::Repos::Statuses;
 use Pithub::Repos::Watching;
+
 extends 'Pithub::Base';
 
 
+sub actions {
+    return shift->_create_instance( Pithub::Repos::Actions::, @_ );
+}
+
+
 sub branch {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: branch (string)' unless defined $args{branch};
@@ -290,10 +300,14 @@ Pithub::Repos - Github v3 Repos API
 
 =head1 VERSION
 
-version 0.01039
+version 0.01040
 
 =head1 METHODS
 
+=head2 actions
+
+Provides access to L<Pithub::Repos::Actions>.
+
 =head2 branch
 
 Get information about a single branch.
